%define ALD_Ver		2.0

%define OrgName ninja

Name:         ninja-build

License:      Apache 2.0
Summary:      Ninja is a small build system with a focus on speed.
Version:      1.10.2
Release:      0
URL: https://github.com/ninja-build/ninja

#BuildRequires: asciidoc

Source: %{OrgName}-%{version}.tar.xz

%define DestDir		/Compiler
# -----------------------------------------------------

%if %{_target_cpu} == %{_build_cpu}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}
%define _CROSS 0
%define MakeLocCross 0
%else
# rpm --target=armv7hl -ba xxxxx.spec
%define _srcrpmdir	%{_topdir}/SRPMS/tmp
%define _CROSS 1
%define MakeLocCross 1
%define _host %{_arch}-%{_os}%{_gnu}
%endif

#------------------ CROSS DIR --------------------

%define docdir		%{_defaultdocdir}/%{name}

%define auto_local %{_sourcedir}/AUTO_LOCAL-1.sh
%define have_auto_local %(if test -x %{auto_local} ; then echo 1 ; else echo 0 ; fi)

%if %{have_auto_local}
%define __os_install_post %{nil}
%define CrossPath	%(%{auto_local} -GetCrossPath -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu})
%endif

# ------------------- description ------------------------------------
%description
Ninja is yet another build system. It takes as input the interdependencies of files (typically source code and output executables) and
orchestrates building them, quickly.

#-------------------------------
%package doc
Summary:      doc for %{name}
Group:        Documentation
%description doc
doc for %{name}

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{OrgName}-%{version}

sed -i s:"'-g', ":: configure.py

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
export  PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

%if %{_arch} == "i386"
OPTFLAGS="-Os -march=i586 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os"
%endif
%if %{_arch} == "arm"
OPTFLAGS="%{optflags} -Os -munaligned-access"
%endif

OPTFLAGS="$OPTFLAGS -fno-asynchronous-unwind-tables -ffunction-sections -fdata-sections"

export CFLAGS="$OPTFLAGS"
export CXXFLAGS=" "
export LDFLAGS="-Wl,--gc-sections -static-libgcc -static-libstdc++"

./configure.py --bootstrap --verbose &>FMake_log.txt 

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
export  PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}
mkdir -p $RPM_BUILD_ROOT%{_bindir}

cp ninja $RPM_BUILD_ROOT%{_bindir}/
ln -s ninja %{buildroot}%{_bindir}/ninja-build

cp -a COPYING README.md doc/manual.asciidoc $RPM_BUILD_ROOT%{docdir}/

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} -DelLocCrossDir=%{_bindir}
%endif  # have_auto_local

# ------------------- Clean ------------------------------------------
%Clean

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} \
	-ALD_Ver=%{ALD_Ver} -RpmMovePath=%{DestDir} -tar_arg=bzip2
%endif  # have_auto_local

# ------------------- Files ------------------------------------------
%files
%{_bindir}
%{docdir}/COPYING
%{docdir}/README.md

%files doc
%{docdir}/manual.asciidoc
